@@ -2,9 +2,9 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2022, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require 'benchmark/ips'
+require "benchmark/ips"
 
 GC.disable
 
