@@ -3,12 +3,12 @@
 # Released under the MIT License.
 # Copyright, 2022-2024, by Samuel Williams.
 
-require 'sus/fixtures/async'
+require "sus/fixtures/async"
 
 describe Kernel do
 	include Sus::Fixtures::Async::ReactorContext
 	
-	with '#sleep' do
+	with "#sleep" do
 		it "can intercept sleep" do
 			expect(reactor).to receive(:kernel_sleep).with(0.001)
 			
@@ -16,16 +16,27 @@ describe Kernel do
 		end
 	end
 	
-	with '#system' do
+	with "#system" do
 		it "can execute child process" do
-			# expect(reactor).to receive(:process_wait)
+			expect(reactor).to receive(:process_wait)
 			
-			::Kernel.system("true")
+			result = ::Kernel.system("true")
+			
+			expect(result).to be == true
 			expect($?).to be(:success?)
 		end
+		
+		it "can fail to execute child process" do
+			expect(reactor).to receive(:process_wait)
+			
+			result = ::Kernel.system("does-not-exist")
+			
+			expect(result).to be == nil
+			expect($?).not.to be(:success?)
+		end
 	end
 	
-	with '#`' do
+	with "#`" do
 		it "can execute child process and capture output" do
 			expect(`echo OK`).to be == "OK\n"
 			expect($?).to be(:success?)
